@@ -192,6 +192,12 @@ class TestProp(unittest.TestCase):
 
         self.assertRaises(ValueError, vDuration, 11)
 
+        # calling to_ical twice should result in same output
+        duration = vDuration(timedelta(days=-1, hours=-5))
+        self.assertEqual(duration.to_ical(), b'-P1DT5H')
+        self.assertEqual(duration.to_ical(), b'-P1DT5H')
+
+
     def test_prop_vPeriod(self):
         from ..prop import vPeriod
 
@@ -455,6 +461,15 @@ class TestProp(unittest.TestCase):
         self.assertIsInstance(t2.params, Parameters)
         self.assertEqual(t2.params, {'CN': 'Test Osterone'})
 
+    def test_prop_vCategory(self):
+        from ..prop import vCategory
+
+        catz = ['cat 1', 'cat 2', 'cat 3']
+        v_cat = vCategory(catz)
+
+        self.assertEqual(v_cat.to_ical(), b'cat 1,cat 2,cat 3')
+        self.assertEqual(vCategory.from_ical(v_cat.to_ical()), catz)
+
     def test_prop_TypesFactory(self):
         from ..prop import TypesFactory
 
